@@ -24,4 +24,8 @@ def loadmods(name):
     this_dir = path.dirname(__file__)
     # figure out where ilstrap/ is
     ilstrap_dir = this_dir + path.sep + "ilstrap" + path.sep + name
-    sys.path.insert(0, ilstrap_dir)
\ No newline at end of file
+    sys.path.insert(0, ilstrap_dir)
+
+
+def accept_file(fd, fname):
+    return 0
